@@ -8,7 +8,9 @@ from django.urls import reverse_lazy
 from django.utils.html import escape
 
 from core_main_app.commons import exceptions
-from core_main_app.components.template.api import init_template_with_dependencies
+from core_main_app.components.template.api import (
+    init_template_with_dependencies,
+)
 from core_main_app.views.admin.ajax import (
     _get_xsd_content_from_html,
     _get_dependencies_dict,
@@ -20,7 +22,9 @@ from core_composer_app.components.type.models import Type
 from core_composer_app.components.type_version_manager import (
     api as type_version_manager_api,
 )
-from core_composer_app.components.type_version_manager.models import TypeVersionManager
+from core_composer_app.components.type_version_manager.models import (
+    TypeVersionManager,
+)
 from core_composer_app.views.admin.forms import EditBucketForm
 
 
@@ -83,7 +87,10 @@ def resolve_dependencies(request):
         else:
             type_version_manager = TypeVersionManager(title=name)
         type_version_manager_api.insert(
-            type_version_manager, type_object, request=request, list_bucket_ids=buckets
+            type_version_manager,
+            type_object,
+            request=request,
+            list_bucket_ids=buckets,
         )
     except Exception as exception:
         return HttpResponseBadRequest(
