@@ -1,5 +1,6 @@
 """ Test settings
 """
+
 SECRET_KEY = "fake-key"
 
 INSTALLED_APPS = [
@@ -53,3 +54,8 @@ DATABASES = {
 
 DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
 CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
+
+CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT = False
+
+MONGODB_INDEXING = False
+MONGODB_ASYNC_SAVE = False
